@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents options of saving .mhtml file.',
                                   class => 'MHtmlSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -164,56 +164,56 @@ __PACKAGE__->method_documentation({
      'save_as_single_file' => {
      	datatype => 'boolean',
      	base_name => 'SaveAsSingleFile',
-     	description => '',
+     	description => 'Indicates whether save the html as single file. The default value is false.',
      	format => '',
      	read_only => '',
      		},
      'export_hidden_worksheet' => {
      	datatype => 'boolean',
      	base_name => 'ExportHiddenWorksheet',
-     	description => '',
+     	description => 'Indicates whether save the html as single file. The default value is false.',
      	format => '',
      	read_only => '',
      		},
      'export_grid_lines' => {
      	datatype => 'boolean',
      	base_name => 'ExportGridLines',
-     	description => '',
+     	description => 'Indicating whether exporting the gridlines.The default value is false.',
      	format => '',
      	read_only => '',
      		},
      'presentation_preference' => {
      	datatype => 'boolean',
      	base_name => 'PresentationPreference',
-     	description => '',
+     	description => 'Indicating if html or mht file is presentation preference.The default value is             false.if you want to get more beautiful presentation,please set the value to                true.',
      	format => '',
      	read_only => '',
      		},
      'cell_css_prefix' => {
      	datatype => 'string',
      	base_name => 'CellCssPrefix',
-     	description => '',
+     	description => 'Gets and sets the prefix of the css name,the default value is "".',
      	format => '',
      	read_only => '',
      		},
      'table_css_id' => {
      	datatype => 'string',
      	base_name => 'TableCssId',
-     	description => '',
+     	description => 'Gets and sets the prefix of the type css name such as tr,col,td and so on, they                are contained in the table element which has the specific TableCssId attribute.                The default value is "".',
      	format => '',
      	read_only => '',
      		},
      'is_full_path_link' => {
      	datatype => 'boolean',
      	base_name => 'IsFullPathLink',
-     	description => '',
+     	description => 'Indicating whether using full path link in sheet00x.htm,filelist.xml and tabstrip.htm.                The default value is false.',
      	format => '',
      	read_only => '',
      		},
      'export_worksheet_css_separately' => {
      	datatype => 'boolean',
      	base_name => 'ExportWorksheetCSSSeparately',
-     	description => '',
+     	description => 'Indicating whether export the worksheet css separately.The default value is false.',
      	format => '',
      	read_only => '',
      		},
@@ -227,98 +227,98 @@ __PACKAGE__->method_documentation({
      'merge_empty_td_forcely' => {
      	datatype => 'boolean',
      	base_name => 'MergeEmptyTdForcely',
-     	description => '',
+     	description => 'Indicates whether merging empty TD element forcely when exporting file to html.                The size of html file will be reduced significantly after setting value to true.                The default value is false. If you want to import the html file to excel or export                perfect grid lines when saving file to html, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_cell_coordinate' => {
      	datatype => 'boolean',
      	base_name => 'ExportCellCoordinate',
-     	description => '',
+     	description => 'Indicates whether exporting excel coordinate of nonblank cells when saving file                to html. The default value is false. If you want to import the output html to                excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_extra_headings' => {
      	datatype => 'boolean',
      	base_name => 'ExportExtraHeadings',
-     	description => '',
+     	description => 'Indicates whether exporting extra headings when the length of text is longer                than max display column. The default value is false. If you want to import the                html file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_headings' => {
      	datatype => 'boolean',
      	base_name => 'ExportHeadings',
-     	description => '',
+     	description => 'Indicates whether exporting headings when saving file to html.The default value                is false. If you want to import the html file to excel, please keep the default                value.',
      	format => '',
      	read_only => '',
      		},
      'export_formula' => {
      	datatype => 'boolean',
      	base_name => 'ExportFormula',
-     	description => '',
+     	description => 'Indicates whether exporting formula when saving file to html. The default value                is true. If you want to import the output html to excel, please keep the default                value',
      	format => '',
      	read_only => '',
      		},
      'add_tooltip_text' => {
      	datatype => 'boolean',
      	base_name => 'AddTooltipText',
-     	description => '',
+     	description => 'Indicates whether adding tooltip text when the data can`t be fully displayed.',
      	format => '',
      	read_only => '',
      		},
      'export_bogus_row_data' => {
      	datatype => 'boolean',
      	base_name => 'ExportBogusRowData',
-     	description => '',
+     	description => 'Indicating whether exporting bogus bottom row data. The default value is true.If you want to import the html or mht file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'exclude_unused_styles' => {
      	datatype => 'boolean',
      	base_name => 'ExcludeUnusedStyles',
-     	description => '',
+     	description => 'Indicating whether excluding unused styles.The default value is false.If you  want to import the html or mht file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_document_properties' => {
      	datatype => 'boolean',
      	base_name => 'ExportDocumentProperties',
-     	description => '',
+     	description => 'Indicating whether exporting document properties.The default value is true.If  you want to import the html or mht file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_worksheet_properties' => {
      	datatype => 'boolean',
      	base_name => 'ExportWorksheetProperties',
-     	description => '',
+     	description => 'Indicating whether exporting worksheet properties.The default value is true.If  you want to import the html or mht file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_workbook_properties' => {
      	datatype => 'boolean',
      	base_name => 'ExportWorkbookProperties',
-     	description => '',
+     	description => 'Indicating whether exporting workbook properties.The default value is true.If  you want to import the html or mht file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'export_frame_scripts_and_properties' => {
      	datatype => 'boolean',
      	base_name => 'ExportFrameScriptsAndProperties',
-     	description => '',
+     	description => 'Indicating whether exporting frame scripts and document properties. The default  value is true.If you want to import the html or mht file to excel, please keep the default value.',
      	format => '',
      	read_only => '',
      		},
      'attached_files_directory' => {
      	datatype => 'string',
      	base_name => 'AttachedFilesDirectory',
-     	description => '',
+     	description => 'The directory that the attached files will be saved to.  Only for saving to html stream.',
      	format => '',
      	read_only => '',
      		},
      'attached_files_url_prefix' => {
      	datatype => 'string',
      	base_name => 'AttachedFilesUrlPrefix',
-     	description => '',
+     	description => 'Specify the Url prefix of attached files such as image in the html file. Only for saving to html stream.',
      	format => '',
      	read_only => '',
      		},
@@ -332,14 +332,14 @@ __PACKAGE__->method_documentation({
      'export_active_worksheet_only' => {
      	datatype => 'boolean',
      	base_name => 'ExportActiveWorksheetOnly',
-     	description => '',
+     	description => 'Indicates if exporting the whole workbook to html file.',
      	format => '',
      	read_only => '',
      		},
      'export_chart_image_format' => {
      	datatype => 'string',
      	base_name => 'ExportChartImageFormat',
-     	description => '',
+     	description => 'Get or set the format of chart image before exporting',
      	format => '',
      	read_only => '',
      		},
@@ -353,42 +353,42 @@ __PACKAGE__->method_documentation({
      'hidden_col_display_type' => {
      	datatype => 'string',
      	base_name => 'HiddenColDisplayType',
-     	description => '',
+     	description => 'Hidden column(the width of this column is 0) in excel,before save this into               html format, if HtmlHiddenColDisplayType is "Remove",the hidden column would               ont been output, if the value is "Hidden", the column would been output,but was hidden,the default value is "Hidden"',
      	format => '',
      	read_only => '',
      		},
      'hidden_row_display_type' => {
      	datatype => 'string',
      	base_name => 'HiddenRowDisplayType',
-     	description => '',
+     	description => 'Hidden row(the height of this row is 0) in excel,before save this into html               format, if HtmlHiddenRowDisplayType is "Remove",the hidden row would ont               been output, if the value is "Hidden", the row would been output,but was               hidden,the default value is "Hidden"',
      	format => '',
      	read_only => '',
      		},
      'html_cross_string_type' => {
      	datatype => 'string',
      	base_name => 'HtmlCrossStringType',
-     	description => '',
+     	description => 'Indicates if a cross-cell string will be displayed in the same way as MS               Excel when saving an Excel file in html format.  By default the value is               Default, so, for cross-cell strings, there is little difference between the               html files created by Aspose.Cells and MS Excel. But the performance for               creating large html files,setting the value to Cross would be several times               faster than setting it to Default or Fit2Cell.',
      	format => '',
      	read_only => '',
      		},
      'is_exp_image_to_temp_dir' => {
      	datatype => 'boolean',
      	base_name => 'IsExpImageToTempDir',
-     	description => '',
+     	description => 'Indicates if export image files to temp directory.  Only for saving to html  stream.',
      	format => '',
      	read_only => '',
      		},
      'page_title' => {
      	datatype => 'string',
      	base_name => 'PageTitle',
-     	description => '',
+     	description => 'The title of the html page.  Only for saving to html stream.',
      	format => '',
      	read_only => '',
      		},
      'parse_html_tag_in_cell' => {
      	datatype => 'boolean',
      	base_name => 'ParseHtmlTagInCell',
-     	description => '',
+     	description => 'Parse html tag in cell,like ,as cell value,or as html tag,default is true',
      	format => '',
      	read_only => '',
      		},
