@@ -305,6 +305,20 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
+     	read_only => '',
+     		},
+     'check_excel_restriction' => {
+     	datatype => 'boolean',
+     	base_name => 'CheckExcelRestriction',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'encrypt_document_properties' => {
+     	datatype => 'boolean',
+     	base_name => 'EncryptDocumentProperties',
+     	description => '',
+     	format => '',
      	read_only => '',
      		},    
 });
@@ -335,7 +349,9 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean' 
+    'validate_merged_areas' => 'boolean',
+    'check_excel_restriction' => 'boolean',
+    'encrypt_document_properties' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -364,7 +380,9 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas' 
+    'validate_merged_areas' => 'ValidateMergedAreas',
+    'check_excel_restriction' => 'CheckExcelRestriction',
+    'encrypt_document_properties' => 'EncryptDocumentProperties' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
