@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -71,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_access_token' } = { 
-    	summary => 'Get Access Token Result: The Cells Cloud Get Token API acts as a proxy service,forwarding user requests to the Aspose Cloud authentication server and returning the resulting access token to the client.',
+    	summary => 'Get Access Token Result',
         params => $params,
         returns => 'string',
     };
@@ -83,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v4.0/cells/connect/token';
+    my $_resource_path = '/cells/connect/token';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -99,9 +98,6 @@ sub run_http_request {
  
  
     my $_body_data;
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
