@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -60,8 +59,7 @@ sub new {
 
 
 # Run Operation Request
-# PostConvertWorkbookRequest.convertWorkbookOptions :   ,
-# PostConvertWorkbookRequest.FontsLocation : Use Custom fonts.   
+# PostConvertWorkbookRequest.convertWorkbookOptions :    
 
 {
     my $params = {
@@ -84,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/convertWorkbook';
+    my $_resource_path = '/cells/convertWorkbook';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -98,19 +96,14 @@ sub run_http_request {
     }
     $header_params->{'Content-Type'} = $client->select_header_content_type('application/json');
  
-    if(defined $self->fonts_location){
-        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
-    } 
+ 
     my $_body_data;
 
-
     # body params
     if (defined $self->convert_workbook_options) {
+        #$_body_data = $self->convert_workbook_options;
          $_body_data = JSON->new->convert_blessed->encode( $self->convert_workbook_options);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -126,21 +119,13 @@ __PACKAGE__->method_documentation({
      	base_name => 'convertWorkbookOptions',
      	description => '',
      	format => '',
-     	read_only => '',
-     		},
-     'fonts_location' => {
-     	datatype => 'string',
-     	base_name => 'FontsLocation',
-     	description => 'Use Custom fonts.',
-     	format => '',
      	read_only => '',
      		},    
 });
 
 
 __PACKAGE__->attribute_map( {
-    'convert_workbook_options' => 'convertWorkbookOptions',
-    'fonts_location' => 'FontsLocation' 
+    'convert_workbook_options' => 'convertWorkbookOptions' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
