@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -83,7 +82,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/datacleansing';
+    my $_resource_path = '/cells/datacleansing';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -100,14 +99,11 @@ sub run_http_request {
  
     my $_body_data;
 
-
     # body params
     if (defined $self->data_cleansing_request) {
+        #$_body_data = $self->data_cleansing_request;
          $_body_data = JSON->new->convert_blessed->encode( $self->data_cleansing_request);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
