@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -64,8 +63,7 @@ sub new {
 # PostImportDataRequest.importOption : Import option. They are include of ImportCSVDataOption, ImportBatchDataOption, ImportPictureOption, ImportStringArrayOption, Import2DimensionStringArrayOption, and so on.    ,
 # PostImportDataRequest.folder : The folder where the file is situated.  ,
 # PostImportDataRequest.storageName : The storage name where the file is situated.  ,
-# PostImportDataRequest.region : The regional settings for workbook.  ,
-# PostImportDataRequest.FontsLocation : Use Custom fonts.   
+# PostImportDataRequest.region : The regional settings for workbook.   
 
 {
     my $params = {
@@ -88,7 +86,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/importdata';
+    my $_resource_path = '/cells/{name}/importdata';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -116,21 +114,14 @@ sub run_http_request {
 
     if(defined $self->region){
         $query_params->{'region'} = $client->to_query_value($self->region);      
-    }
-
-    if(defined $self->fonts_location){
-        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
 
-
     # body params
     if (defined $self->import_option) {
+        #$_body_data = $self->import_option;
          $_body_data = JSON->new->convert_blessed->encode( $self->import_option);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
@@ -174,13 +165,6 @@ __PACKAGE__->method_documentation({
      	base_name => 'region',
      	description => 'The regional settings for workbook.',
      	format => '',
-     	read_only => '',
-     		},
-     'fonts_location' => {
-     	datatype => 'string',
-     	base_name => 'FontsLocation',
-     	description => 'Use Custom fonts.',
-     	format => '',
      	read_only => '',
      		},    
 });
@@ -191,8 +175,7 @@ __PACKAGE__->attribute_map( {
     'import_option' => 'importOption',
     'folder' => 'folder',
     'storage_name' => 'storageName',
-    'region' => 'region',
-    'fonts_location' => 'FontsLocation' 
+    'region' => 'region' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
