@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -89,7 +88,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/listobjects/{listObjectIndex}/listcolumns/{columnIndex}';
+    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/listobjects/{listObjectIndex}/listcolumns/{columnIndex}';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -134,14 +133,11 @@ sub run_http_request {
     } 
     my $_body_data;
 
-
     # body params
     if (defined $self->list_column) {
+        #$_body_data = $self->list_column;
          $_body_data = JSON->new->convert_blessed->encode( $self->list_column);
     }
-
- 
-
     # authentication setting, if any
     my $auth_settings = [qw()];
 
